#
# (c) System csh.cshrc for tcsh, Werner Fink '93
#                       and  J"org Stadler '94
# Zusamengetragen, modifiziert, ergaenzt ...
# u.a. aus den Sourcen der tcsh und der man page und ...
#
# 1999/06/25:	<werner@suse.de>: move completion handling into
#		 complete.tcsh and key bindings into bindkey.tcsh,
#		 implement a bypass for experts.
#
onintr -
#
# Default echo style
#
set echo_style=both
#
setenv OPENWINHOME /usr/openwin
setenv HELPPATH $OPENWINHOME/lib/help
setenv MANPATH  "`(unsetenv MANPATH; manpath -q)`"
setenv MINICOM  "-c on"
setenv HOSTNAME "`hostname -f`"
setenv HOST     "`hostname -s`"
if ( -f /etc/organization ) then
   setenv ORGANIZATION "`cat /etc/organization`"
endif
setenv MACHTYPE `uname -m`
setenv LESSCHARSET latin1
setenv LESS -sM
setenv LESSOPEN "|lesspipe.sh %s"
if ( -f /etc/lesskey.bin ) then
   setenv LESSKEY /etc/lesskey.bin
endif
setenv MORE -sl
setenv PAGER '/usr/bin/less -sM'
setenv GZIP -9
setenv CSHEDIT emacs
setenv INFODIR /usr/info:/usr/share/info:/usr/local/info
setenv INFOPATH $INFODIR
if ( -s /etc/nntpserver ) then
   setenv NNTPSERVER `cat /etc/nntpserver`
else
   setenv NNTPSERVER news
endif
#
set XLIBDIR=/usr/X11R6/lib/X11/
if ( -d /usr/lib/X11/app-defaults/ ) then
    set XLIBDIR=/usr/lib/X11/
endif
set path_xr5=${XLIBDIR}%L/%T/%N%C:${XLIBDIR}%l/%T/%N%C:${XLIBDIR}%T/%N%C
set path_xr6=${XLIBDIR}%L/%T/%N:${XLIBDIR}%l/%T/%N:${XLIBDIR}%T/%N
set path_var=/var/X11R6/%T/%N%C:/var/X11R6/%T/%N
setenv XFILESEARCHPATH "${path_xr5}:${path_xr6}:${path_var}"
if ( -d ${HOME}/.app-defaults/ ) then
    setenv XAPPLRESDIR  ${HOME}/.app-defaults/
endif
unset XLIBDIR path_xr5 path_xr6 path_var
#
if ( -f /usr/lib/teTeX/texmf.cnf ) then
   setenv TETEXDIR /usr/lib/teTeX
   if ( -d /usr/bin/TeX ) set path=( /usr/bin/TeX $path )
endif
#
# Which C-lib or locale db takes what?
# setenv LC_CTYPE iso_8859_1
# setenv LC_CTYPE ISO8859-1
# setenv LC_CTYPE ISO-8859-1
# setenv LC_CTYPE de_DE
# setenv LC_CTYPE en_GB
# setenv LANG de_DE
#
if (-r /etc/inputrc) setenv INPUTRC /etc/inputrc
setenv COLORTERM 1
#
# SuSEconfig stuff
#
if ( -r /etc/SuSEconfig/csh.cshrc ) then
    source /etc/SuSEconfig/csh.cshrc
endif
#
# source extensions for special packages
#
if ( -d /etc/profile.d ) then
  set _tmp=${?nonomatch}
  set nonomatch
  foreach _s ( /etc/profile.d/*.csh )
    if ( -r $_s ) then
      source $_s
    endif
  end
  if ( ! ${_tmp} ) unset nonomatch
  unset _tmp _s
endif
#
#
if (! ${?prompt}) goto end
#
# This is an interactive session
#
# Now read in the key bindings of the tcsh
#
if ($?tcsh && -r /etc/profile.d/bindkey.tcsh) source /etc/profile.d/bindkey.tcsh

#
# Expert mode: if we find $HOME/.csh.expert we skip our settings
# used for interactive sessions and read in the expert file.
#
if (-r $HOME/.csh.expert) then
    source $HOME/.csh.expert
    goto end
endif

#
# Some useful settings
#
set autocorrect=1
set listmaxrows=23
# set cdpath = ( /var/spool )
# set complete=enhance
# set correct=all
set correct=cmd
set fignore=(.o \~)
# set histdup=prev
set histdup=erase
set history=100
set listjobs=long
set notify=1
set nostat=( /afs )
set rmstar=1
set savehist=( $history merge )
set showdots=1
set symlinks=expand
#
unset autologout
unset ignoreeof
#
set noglob
if ( -x /usr/bin/dircolors ) then
    if ( -r $HOME/.dir_colors ) then
	eval `dircolors -c $HOME/.dir_colors`
    else if ( -r /etc/DIR_COLORS ) then
	eval `dircolors -c /etc/DIR_COLORS`
    endif
endif
unalias ls
if ( "$uid" == "0" ) then
    setenv LS_OPTIONS '-a -N --color=tty -T 0';
else
    setenv LS_OPTIONS '-N --color=tty -T 0';
endif
alias ls 'ls $LS_OPTIONS'
alias la 'ls -AF --color=none'
alias ll 'ls -l  --color=none'
alias l  'll'
alias dir  'ls --format=vertical'
alias vdir 'ls --format=long'
alias d dir;
alias v vdir;
# Handle emacs
if ($?EMACS) then
  setenv LS_OPTIONS '-N --color=none -T 0';
  tset -I -Q
  stty cooked pass8 dec nl -echo
  if ($?tcsh) unset edit
endif
unset noglob

#
# Prompting and Xterm title
#
set prompt="%B%m%b %C2%# "
alias cwdcmd '(echo "Directory: $cwd" > /dev/tty)'
if ( -o /dev/$tty && -x /usr/bin/biff ) /usr/bin/biff y
#
if ( ${?WINDOWID} && ${?EMACS} == 0 ) then
  alias cwdcmd '(echo -n "\033]2;$USER on ${HOST}: $cwd\007\033]1;$HOST\007" > /dev/tty)'
  cd .
endif
#
if ( -o /dev/$tty && ${?DISPLAY} ) then
  if ( -x /usr/bin/biff ) /usr/bin/biff n
  set prompt="%C2%# "
endif
#
# tcsh help system does search for uncompressed helps file
# within the cat directory system of a old manual page system.
# Therefore we use whatis as alias for this helpcommand
#
alias helpcommand whatis

#
# Source the completion extension of the tcsh
#
if ($?tcsh) then
    set _rev=${tcsh:r}
    set _rel=${_rev:e}
    set _rev=${_rev:r}
    if ($_rel > 5 && $_rev > 1 && -r /etc/profile.d/complete.tcsh) then
	source /etc/profile.d/complete.tcsh
    endif
    unset _rev _rel
endif
#
end:
    onintr
#
# csh.cshrc end here
#
